@@ -7,6 +7,8 @@ from plogger import logger
 class SocketClient:
     """Create socket and establish connect to service using tuple host+port"""
 
+    greeting = None
+
     def __init__(self,
                  host: str,
                  port: int = 0,
@@ -23,7 +25,7 @@ class SocketClient:
 
         self.host = host
         self.port = port
-        self.logger = logger(self.__class__.__name__, enabled=logger_enabled)
+        self.logger = logger('SocketClient', enabled=logger_enabled)
         self.connection_timeout = connection_timeout
 
         if initialize:
@@ -39,7 +41,7 @@ class SocketClient:
 
     def __getattr__(self, attr):
         self.logger.error(f'No such attribute ({attr}) error. Perhaps, object is not initialized.')
-        raise AttributeError(f'{self.__class__.__name__}() does not have specific attribute "{attr}"')
+        raise AttributeError(f'SocketClient does not have specific attribute "{attr}"')
 
     def __str__(self):
         msg = f'[{self.host} {self._receive_all()}]'
@@ -51,6 +53,7 @@ class SocketClient:
         :param timeout:
         :return:
         """
+
         return socket.create_connection((self.host, self.port), timeout=timeout)
 
     def is_socket_available(self,
@@ -104,11 +107,6 @@ class SocketClient:
                 raise TimeoutError(error_msg)
         return status
 
-    def _greeting(self):
-        """Works only for the first connection in all project"""
-
-        return self._receive_all()
-
     def send_command(self, cmd: str = '', timeout: float = None):
         """Send network command and receive response.
 
@@ -119,14 +117,20 @@ class SocketClient:
 
         command = self._encode_command(cmd)
 
-        self.logger.info(f'[{self.host} -->] {cmd}')
+        self.logger.info(f'[{self.host}] -> {cmd}')
 
         try:
             self.client.sendall(command)
             response = self._receive_all(timeout)
+
+            # Save the greeting message for the first time only
+            if self.greeting is None:
+                self.greeting = response
+
             return response
         except AttributeError as err:
             self.logger.error(f'[{self.host}] {err}')
+            raise err
 
     def _receive_all(self, timeout: Union[float, None] = None, buffer_size: int = 4096):
         """Get and decode socket response
@@ -149,11 +153,12 @@ class SocketClient:
                         break
                     data.extend(chunk)
             except socket.timeout:
-                self.logger.debug(f'[{self.host} <--] Socket read timeout ({timeout})')
+                self.logger.warning(f'[{self.host}] <- Socket read timeout ({timeout})')
                 self.client.settimeout(None)  # Set blocking
 
-        response = data.decode().strip().split('\n')
-        self.logger.info(f'[{self.host} <--] {response}')
+        response = data.decode().strip().splitlines()
+
+        self.logger.info(f'[{self.host}] <- {response}')
         return response
 
     def close_connection(self):
